@@ -1,6 +1,7 @@
 # coding: utf-8
 import os
 import types
+from datetime import datetime
 
 def mergeObj(ori={}, *objs):
     '''合并字典'''
@@ -26,3 +27,14 @@ def get_width(ans):
                 times += 1
         width = len(ans) + times
     return width, times
+
+def parseJsonp(text):
+    # 解析jsonp数据返回dict数据
+    import json5
+    start = text.find('(') + 1
+    end = text.rfind(')')
+    return json5.loads(text[start:end])
+
+def currentTimestamp():
+    # 当前时间戳
+    return int(datetime.timestamp(datetime.now()) * 10000)
